summaryrefslogtreecommitdiffstats
path: root/crypto/engine
diff options
context:
space:
mode:
Diffstat (limited to 'crypto/engine')
-rw-r--r--crypto/engine/eng_cryptodev.c6
-rw-r--r--crypto/engine/eng_dyn.c2
-rw-r--r--crypto/engine/eng_int.h2
-rw-r--r--crypto/engine/eng_lib.c4
-rw-r--r--crypto/engine/eng_list.c2
-rw-r--r--crypto/engine/eng_openssl.c2
-rw-r--r--crypto/engine/eng_rdrand.c4
7 files changed, 11 insertions, 11 deletions
diff --git a/crypto/engine/eng_cryptodev.c b/crypto/engine/eng_cryptodev.c
index ab896d775a..151529c951 100644
--- a/crypto/engine/eng_cryptodev.c
+++ b/crypto/engine/eng_cryptodev.c
@@ -63,7 +63,7 @@
#ifndef HAVE_CRYPTODEV
-void int_engine_load_cryptodev(void)
+void engine_load_cryptodev_int(void)
{
/* This is a NOP on platforms without /dev/crypto */
return;
@@ -141,7 +141,7 @@ static int cryptodev_dh_compute_key(unsigned char *key, const BIGNUM *pub_key,
#endif
static int cryptodev_ctrl(ENGINE *e, int cmd, long i, void *p,
void (*f) (void));
-void int_engine_load_cryptodev(void);
+void engine_load_cryptodev_int(void);
static const ENGINE_CMD_DEFN cryptodev_defns[] = {
{0, NULL, NULL, 0}
@@ -1628,7 +1628,7 @@ cryptodev_ctrl(ENGINE *e, int cmd, long i, void *p, void (*f) (void))
return (1);
}
-void int_engine_load_cryptodev(void)
+void engine_load_cryptodev_int(void)
{
ENGINE *engine = ENGINE_new();
int fd;
diff --git a/crypto/engine/eng_dyn.c b/crypto/engine/eng_dyn.c
index 33c9f666a9..f224255851 100644
--- a/crypto/engine/eng_dyn.c
+++ b/crypto/engine/eng_dyn.c
@@ -295,7 +295,7 @@ static ENGINE *engine_dynamic(void)
return ret;
}
-void int_engine_load_dynamic(void)
+void engine_load_dynamic_int(void)
{
ENGINE *toadd = engine_dynamic();
if (!toadd)
diff --git a/crypto/engine/eng_int.h b/crypto/engine/eng_int.h
index ca9733c7a6..beaa878e36 100644
--- a/crypto/engine/eng_int.h
+++ b/crypto/engine/eng_int.h
@@ -99,7 +99,7 @@ extern CRYPTO_RWLOCK *global_engine_lock;
/*
* Any code that will need cleanup operations should use these functions to
- * register callbacks. int_engine_cleanup() will call all registered
+ * register callbacks. engine_cleanup_int() will call all registered
* callbacks in order. NB: both the "add" functions assume the engine lock to
* already be held (in "write" mode).
*/
diff --git a/crypto/engine/eng_list.c b/crypto/engine/eng_list.c
index a66be7f17c..15ba1ca33d 100644
--- a/crypto/engine/eng_list.c
+++ b/crypto/engine/eng_list.c
@@ -79,7 +79,7 @@ static ENGINE *engine_list_tail = NULL;
/*
* This cleanup function is only needed internally. If it should be called,
- * we register it with the "int_engine_cleanup()" stack to be called during
+ * we register it with the "engine_cleanup_int()" stack to be called during
* cleanup.
*/
diff --git a/crypto/engine/eng_openssl.c b/crypto/engine/eng_openssl.c
index 40290e3f5a..fa26700d1e 100644
--- a/crypto/engine/eng_openssl.c
+++ b/crypto/engine/eng_openssl.c
@@ -189,7 +189,7 @@ static ENGINE *engine_openssl(void)
return ret;
}
-void int_engine_load_openssl(void)
+void engine_load_openssl_int(void)
{
ENGINE *toadd = engine_openssl();
if (!toadd)
diff --git a/crypto/engine/eng_rdrand.c b/crypto/engine/eng_rdrand.c
index 093b7f6312..b62f9109ed 100644
--- a/crypto/engine/eng_rdrand.c
+++ b/crypto/engine/eng_rdrand.c
@@ -130,7 +130,7 @@ static ENGINE *ENGINE_rdrand(void)
return ret;
}
-void int_engine_load_rdrand(void)
+void engine_load_rdrand_int(void)
{
extern unsigned int OPENSSL_ia32cap_P[];
@@ -144,7 +144,7 @@ void int_engine_load_rdrand(void)
}
}
#else
-void int_engine_load_rdrand(void)
+void engine_load_rdrand_int(void)
{
}
#endif
diff --git a/crypto/engine/eng_lib.c b/crypto/engine/eng_lib.c
index 64c3b374f6..d0bc716bb3 100644
--- a/crypto/engine/eng_lib.c
+++ b/crypto/engine/eng_lib.c
@@ -148,7 +148,7 @@ int ENGINE_free(ENGINE *e)
/* Cleanup stuff */
/*
* int_engine_cleanup() is coded such that anything that does work that will
* need cleanup can register a "cleanup" callback here. That way we don't get
* linker bloat by referring to all *possible* cleanups, but any linker bloat
* into code "X" will cause X's cleanup function to end up here.
@@ -200,7 +200,7 @@ static void engine_cleanup_cb_free(ENGINE_CLEANUP_ITEM *item)
OPENSSL_free(item);
}
-void int_engine_cleanup(void)
+void engine_cleanup_int(void)
{
if (int_cleanup_check(0)) {
sk_ENGINE_CLEANUP_ITEM_pop_free(cleanup_stack,
@@ -148,7 +148,7 @@ int ENGINE_free(ENGINE *e)
/* Cleanup stuff */
/*
- * int_engine_cleanup() is coded such that anything that does work that will
+ * engine_cleanup_int() is coded such that anything that does work that will
* need cleanup can register a "cleanup" callback here. That way we don't get
* linker bloat by referring to all *possible* cleanups, but any linker bloat